@@ -8,9 +8,14 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package MooseX::RelatedClasses;
-{
-  $MooseX::RelatedClasses::VERSION = '0.006';
+BEGIN {
+  $MooseX::RelatedClasses::AUTHORITY = 'cpan:RSRCHBOY';
 }
+{
+  $MooseX::RelatedClasses::VERSION = '0.007';
+}
+# git description: 0.006-8-ge6e6247
+
 
 # ABSTRACT: Parameterized role for related class attributes
 
@@ -18,7 +23,7 @@ use MooseX::Role::Parameterized;
 use namespace::autoclean;
 use autobox::Core;
 use autobox::Camelize;
-use MooseX::AttributeShortcuts 0.019;
+use MooseX::AttributeShortcuts 0.020;
 use MooseX::Types::Common::String ':all';
 use MooseX::Types::LoadableClass ':all';
 use MooseX::Types::Perl ':all';
@@ -30,10 +35,6 @@ use Module::Find 'findallmod';
 use Class::Load 'load_class';
 use String::RewritePrefix;
 
-# debugging...
-#use Smart::Comments '###';
-#use autobox::JSON;
-
 use Moose::Exporter;
 Moose::Exporter->setup_import_methods(
     with_meta => [ qw{ related_classes related_class } ],
@@ -64,10 +65,10 @@ parameter names => (
 
     isa        => HashRef[Identifier],
     constraint => sub { do { is_PackageName($_) or die 'keys must be PackageName' } for $_->keys; 1 },
-    coerce     => {
-        ArrayRef()    => sub { +{ map { $_ => $_->decamelize } @$_ } },
-        PackageName() => sub { +{       $_ => $_->decamelize       } },
-    },
+    coerce     => [
+        ArrayRef              => sub { +{ map { $_ => $_->decamelize } @$_ } },
+        PackageName()->name() => sub { +{       $_ => $_->decamelize       } },
+    ],
 
     default => sub { confess 'name parameter required!' unless $_[0]->has_name; $_[0]->name },
 );
@@ -197,7 +198,7 @@ MooseX::RelatedClasses - Parameterized role for related class attributes
 
 =head1 VERSION
 
-This document describes version 0.006 of MooseX::RelatedClasses - released July 12, 2013 as part of MooseX-RelatedClasses.
+This document describes version 0.007 of MooseX::RelatedClasses - released August 22, 2013 as part of MooseX-RelatedClasses.
 
 =head1 SYNOPSIS
 
